import java.math.BigInteger;
import java.util.Arrays;
import java.util.StringTokenizer;

import ru.ifmo.testlib.InStream;
import ru.ifmo.testlib.Outcome;
import ru.ifmo.testlib.Outcome.Type;

public class Check implements ru.ifmo.testlib.Checker {

	final String impossible = "Impossible".toLowerCase();

	@Override
	public Outcome test(InStream inf, InStream ouf, InStream ans) {
		int n = inf.nextInt();
		long k = inf.nextLong();
		String pa = ouf.nextLine().trim().toLowerCase();
		String ja = ans.nextLine().trim().toLowerCase();
		if (pa.equals(impossible)) {
			if (ja.equals(impossible)) {
				return new Outcome(Type.OK, "Impossible");
			}
			return new Outcome(Type.WA,
					"participant hasn't found solution, but jury has one");
		}
		StringTokenizer st = new StringTokenizer(pa);
		int[] a = new int[n];
		n = 0;
		while (st.hasMoreTokens()) {
			if (n >= a.length) {
				return new Outcome(Type.PE, "too many numbers in output");
			}
			String s = st.nextToken();
			try {
				a[n++] = Integer.parseInt(s);
			} catch (NumberFormatException e) {
				return new Outcome(Type.PE, "integer expected, but \"" + s
						+ "\" found");
			}
		}
		if (n < a.length) {
			return new Outcome(Type.PE, "not enough numbers in output");
		}
		if (a[0] != 1) {
			return new Outcome(Type.WA, "first integer is not one: " + a[0]);
		}
		if (a[n - 1] != 1) {
			return new Outcome(Type.WA, "last integer is not one: " + a[n - 1]);
		}
		for (int i = 0; i < a.length; i++) {
			if (a[i] != 0 && a[i] != 1) {
				return new Outcome(Type.PE, "unexpected integer: " + a[i]);
			}
		}
		BigInteger[] d = new BigInteger[a.length];
		Arrays.fill(d, BigInteger.ZERO);
		d[0] = BigInteger.ONE;
		for (int i = 1; i < d.length; i++) {
			if (a[i] == 0) {
				continue;
			}
			d[i] = d[i - 1];
			if (i - 2 >= 0) {
				d[i] = d[i].add(d[i - 2]);
			}
		}
		if (d[n - 1].equals(BigInteger.valueOf(k))) {
			if (ja.equals(impossible)) {
				return new Outcome(Type.FAIL, "participant has found solution");
			}
			return new Outcome(Type.OK, "ok");
		} else {
			return new Outcome(Type.WA, "wrong number of ways: " + k
					+ " expected, but " + d[n - 1] + " found"
					+ (ja.equals(impossible) ? " (ja: impossible)" : ""));
		}
	}
}
